==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDensityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDetailDescription } from "./WebDensityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebDensityChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDensityChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebDensityChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebDensityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDensityChangedEventArgsDetailDescriptionMetadata.c(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebDensityChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DensityChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("OldDensity", "ExportedType:string:DisplayDensity");
            a.item("OldDensity@names", "Comfortable;Cosy;Compact");
            a.item("NewDensity", "ExportedType:string:DisplayDensity");
            a.item("NewDensity@names", "Comfortable;Cosy;Compact");
        }
        static d(a) {
            WebDensityChangedEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebDensityChangedEventArgsDetail", () => new WebDensityChangedEventArgsDetailDescription());
            a.z("WebDensityChangedEventArgsDetail", WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebDensityChangedEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDensityChangedEventArgsDetailDescriptionMetadata, 'WebDensityChangedEventArgsDetailDescriptionMetadata');
    WebDensityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDensityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDetailDescription } from "./WebDensityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebDensityChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDensityChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebDensityChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebDensityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDensityChangedEventArgsDetailDescriptionMetadata.c(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebDensityChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DensityChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldDensity", "ExportedType:string:DisplayDensity");
            a.item("OldDensity@stringUnion", "WebComponents;React");
            a.item("OldDensity@names", "Comfortable;Cosy;Compact");
            a.item("NewDensity", "ExportedType:string:DisplayDensity");
            a.item("NewDensity@stringUnion", "WebComponents;React");
            a.item("NewDensity@names", "Comfortable;Cosy;Compact");
        }
        static d(a) {
            WebDensityChangedEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebDensityChangedEventArgsDetail", () => new WebDensityChangedEventArgsDetailDescription());
            a.ab("WebDensityChangedEventArgsDetail", WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebDensityChangedEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDensityChangedEventArgsDetailDescriptionMetadata, 'WebDensityChangedEventArgsDetailDescriptionMetadata');
    WebDensityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDetailDescriptionMetadata;
})();
